api.reputation.v1.override package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.override package

## Submodules

## api.reputation.v1.override.override_domain module

Autogenerated API

`api.reputation.v1.override.override_domain.` `add_address_overrides`(listName: str = None, listID: int = None, overrides: list = None, clear: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add reputation IP override (INTERNAL)

  Return type: | `dict`
  Parameters: | listName (str) – listID (int) – overrides (list) – clear (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 679, “limit”: 661, “responseCode”: 200, “count”: 857, “data”: [{“id”: 230, “flags”: 959, “listName”: “Role star concern two three.”, “defaultValue”: false, “deleted”: false, “expired”: true, “lastUpdatedTimestamp”: 777216640}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Full police region a decision alone question.”, “messageTemplate”: “Month agreement medical player.”, “field”: “Also perform dark enough customer establish everything.”, “parameter”: {}, “timestamp”: 1142051738}], “currentPage”: 775, “size”: 464}

`api.reputation.v1.override.override_domain.` `add_domain_override`(listID: int = None, listName: str = None, overrides: list = None, clear: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add reputation domain override (INTERNAL)

  Return type: | `dict`
  Parameters: | listID (int) – listName (str) – overrides (list) – clear (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 322, “limit”: 374, “responseCode”: 200, “count”: 914, “data”: [{“id”: 671, “flags”: 304, “listName”: “When station take six us hot.”, “defaultValue”: true, “domainPatternBase”: “Drop amount value laugh get important require.”, “domainPattern”: “Usually party production consider improve sea responsibility.”, “publicPrefixMatch”: true, “wildcardMatch”: false, “deleted”: false, “expired”: true, “lastUpdatedTimestamp”: 1019857552}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Response decide along difference care.”, “messageTemplate”: “Also window question bank most senior.”, “field”: “Whom skill blue stock give have but.”, “parameter”: {}, “timestamp”: 937677805}], “currentPage”: 99, “size”: 694}

`api.reputation.v1.override.override_domain.` `add_override_list`(name: str = None, description: str = None, useForReputationCalc: bool = 'False', useForInputFiltering: bool = 'False', useForDefaultValues: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add reputation override list (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – Override list name => [a-zA-Z0-9_-.]* description (str) – Override list description => [sw{}$-().[]“‘_/,*+#:@!?;]* useForReputationCalc (bool) – If true, enable use of the overrides in this list when calculating reputation values. (default false) useForInputFiltering (bool) – If true, enable use of the overrides in this list for observation input filtering. (default false) useForDefaultValues (bool) – If true, enable use of the overrides in this list as default values. (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 122, “limit”: 684, “responseCode”: 200, “count”: 20, “data”: [{“id”: 787, “lastModified”: 363, “name”: “Theresa Combs”, “description”: “Go structure conference style ever.”, “defaultValues”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “On measure instead hard stay worry forget.”, “messageTemplate”: “One before easy.”, “field”: “Lay effort teacher charge identify human spend.”, “parameter”: {}, “timestamp”: 119086422}], “currentPage”: 964, “size”: 999}

`api.reputation.v1.override.override_domain.` `delete_address_override`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation IP override (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of override entry to remove
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 897, “limit”: 569, “responseCode”: 200, “count”: 248, “data”: [{“id”: 532, “flags”: 788, “listName”: “Experience enough better market agreement.”, “defaultValue”: true, “deleted”: false, “expired”: false, “lastUpdatedTimestamp”: 605837813}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Trouble friend expert.”, “messageTemplate”: “Create mouth than describe.”, “field”: “Market admit begin crime nature.”, “parameter”: {}, “timestamp”: 661752037}], “currentPage”: 236, “size”: 909}

`api.reputation.v1.override.override_domain.` `delete_address_overrides`(id: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Bulk delete reputation IP overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | id (list) – IDs of IP overrides
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 202, “limit”: 719, “responseCode”: 200, “count”: 907, “data”: [{“id”: 92, “flags”: 801, “listName”: “Wall seem approach for.”, “defaultValue”: true, “deleted”: true, “expired”: true, “lastUpdatedTimestamp”: 823535973}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Politics agreement both feel event room.”, “messageTemplate”: “Hair show either politics.”, “field”: “Present degree training size crime prevent painting.”, “parameter”: {}, “timestamp”: 641151776}], “currentPage”: 798, “size”: 128}

`api.reputation.v1.override.override_domain.` `delete_domain_override`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation domain override (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of override entry to remove
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 975, “limit”: 190, “responseCode”: 200, “count”: 181, “data”: [{“id”: 96, “flags”: 886, “listName”: “Middle soldier month half group process figure reality.”, “defaultValue”: false, “domainPatternBase”: “Message debate her guy know long drive.”, “domainPattern”: “Red might deal can.”, “publicPrefixMatch”: true, “wildcardMatch”: false, “deleted”: false, “expired”: true, “lastUpdatedTimestamp”: 611692120}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Professional option why lay finish including bar.”, “messageTemplate”: “See hard become region evidence science center include.”, “field”: “Board some improve car say fight recognize bank.”, “parameter”: {}, “timestamp”: 1285825335}], “currentPage”: 275, “size”: 63}

`api.reputation.v1.override.override_domain.` `delete_domain_overrides`(id: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Bulk delete reputation domain overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | id (list) – IDs of reputation overrides
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 320, “limit”: 574, “responseCode”: 200, “count”: 67, “data”: [{“id”: 298, “flags”: 255, “listName”: “Case success involve speech push compare act.”, “defaultValue”: true, “domainPatternBase”: “Happy personal newspaper.”, “domainPattern”: “Certainly interview young owner program force maintain.”, “publicPrefixMatch”: true, “wildcardMatch”: false, “deleted”: false, “expired”: false, “lastUpdatedTimestamp”: 1431814766}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Matter bill language court thought response.”, “messageTemplate”: “Foreign other church argue.”, “field”: “Range way serious fund drop happy final.”, “parameter”: {}, “timestamp”: 312867132}], “currentPage”: 482, “size”: 327}

`api.reputation.v1.override.override_domain.` `delete_override_list`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete reputation override list (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of override list to remove
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 237, “limit”: 475, “responseCode”: 200, “count”: 648, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Wish TV him near in.”, “messageTemplate”: “Citizen firm report idea.”, “field”: “Recently measure real accept way.”, “parameter”: {}, “timestamp”: 810702741}], “currentPage”: 296, “size”: 776}

`api.reputation.v1.override.override_domain.` `find_address_overrides`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, listID: list = None, listName: list = None, includedListFlags: int = None, excludedListFlags: int = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, minValue: int = None, maxValue: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, ranges: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeExpired: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search IP overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – listID (list) – Collection of override lists’ IDs listName (list) – Collection of override lists’ names includedListFlags (int) – Include records with flags in override list excludedListFlags (int) – Exclude records with flags in override list startTimestamp (int) – Records after this timestamp against fields defined by timeFieldStrategy endTimestamp (int) – Records before this timestamp against fields defined by timeFieldStrategy timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match, default lastUpdatedTimestamp minValue (int) – Lower bound for override value range [0,1] maxValue (int) – Upper bound for override data value range [0,1] keywords (list) – Set of keywords to match selected fields, depends on KeywordMatchStrategy keywordMatchStrategy (str) – Define whether all/any keywords have to be matched with selected fields timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) ranges (list) – Collection of IPRanges keywordFieldStrategy (list) – Define which field(s) to be matched against keywords sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeExpired (bool) – Whether include expired overrides, default not include expired overrides
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 2, “limit”: 391, “responseCode”: 200, “count”: 582, “data”: [{“id”: 807, “flags”: 486, “listName”: “Side less situation piece.”, “defaultValue”: false, “deleted”: true, “expired”: false, “lastUpdatedTimestamp”: 1016746261}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Leader every picture decide someone important final.”, “messageTemplate”: “Central go help star.”, “field”: “Region well increase.”, “parameter”: {}, “timestamp”: 824174210}], “currentPage”: 524, “size”: 445}

`api.reputation.v1.override.override_domain.` `find_domain_overrides`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, listID: list = None, listName: list = None, includedListFlags: int = None, excludedListFlags: int = None, startTimestamp: int = None, endTimestamp: int = None, timeFieldStrategy: list = None, minValue: int = None, maxValue: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, domainPatternBases: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeExpired: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search domain overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – listID (list) – Collection of override lists’ IDs listName (list) – Collection of override lists’ names includedListFlags (int) – Include records with flags in override list excludedListFlags (int) – Exclude records with flags in override list startTimestamp (int) – Records after this timestamp against fields defined by timeFieldStrategy endTimestamp (int) – Records before this timestamp against fields defined by timeFieldStrategy timeFieldStrategy (list) – TimeFieldStrategy to define which timestamp field(s) to match, default lastUpdatedTimestamp minValue (int) – Lower bound for override value range [0,1] maxValue (int) – Upper bound for override data value range [0,1] keywords (list) – Set of keywords to match selected fields, depends on KeywordMatchStrategy keywordMatchStrategy (str) – Define whether all/any keywords have to be matched with selected fields timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) domainPatternBases (list) – Collection of domain pattern bases keywordFieldStrategy (list) – Define which field(s) to be matched against keywords sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeExpired (bool) – Whether include expired overrides, default not include expired overrides
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 560, “limit”: 728, “responseCode”: 200, “count”: 965, “data”: [{“id”: 741, “flags”: 978, “listName”: “Well ten girl increase section recognize nearly current.”, “defaultValue”: false, “domainPatternBase”: “Able so peace research expect fight think site.”, “domainPattern”: “Fear hundred price environment side player.”, “publicPrefixMatch”: true, “wildcardMatch”: false, “deleted”: true, “expired”: false, “lastUpdatedTimestamp”: 219319579}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Few serious herself stay project.”, “messageTemplate”: “Product help financial ability around contain human leg.”, “field”: “Place ready here government.”, “parameter”: {}, “timestamp”: 708290208}], “currentPage”: 549, “size”: 462}

`api.reputation.v1.override.override_domain.` `get_override_for_domain`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up domain override value by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of override object
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 37, “limit”: 768, “responseCode”: 200, “count”: 467, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Peace well suddenly trouble.”, “messageTemplate”: “Hundred add central arm article.”, “field”: “Keep stop politics stock break store receive.”, “parameter”: {}, “timestamp”: 924372700}], “currentPage”: 882, “size”: 522}

`api.reputation.v1.override.override_domain.` `get_override_for_i_p`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up IP override value by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of override object
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 837, “limit”: 301, “responseCode”: 200, “count”: 446, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “That begin wonder.”, “messageTemplate”: “Yard prepare large.”, “field”: “Discussion three large right organization.”, “parameter”: {}, “timestamp”: 781663604}], “currentPage”: 837, “size”: 113}

`api.reputation.v1.override.override_domain.` `get_override_list_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get override list by ID (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of OverrideList
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 544, “limit”: 373, “responseCode”: 200, “count”: 287, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Deep parent operation.”, “messageTemplate”: “Physical increase right world poor behind finally.”, “field”: “His about movie morning about often building.”, “parameter”: {}, “timestamp”: 1017368563}], “currentPage”: 993, “size”: 108}

`api.reputation.v1.override.override_domain.` `get_override_lists`(keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List all overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | keywords (list) – Filter override lists by keywords offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 885, “limit”: 859, “responseCode”: 200, “count”: 239, “data”: [{“id”: 810, “lastModified”: 261, “name”: “Jason Turner”, “description”: “Imagine question condition.”, “defaultValues”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Offer among Congress involve mother trip.”, “messageTemplate”: “Increase material nature building play government firm.”, “field”: “Continue success father front.”, “parameter”: {}, “timestamp”: 1205810339}], “currentPage”: 654, “size”: 668}

`api.reputation.v1.override.override_domain.` `get_overrides_for_domain`(fqdn: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up domain override value by IP address (INTERNAL)

  Return type: | `dict`
  Parameters: | fqdn (str) – Domain/domain pattern to fetch overrides for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 383, “limit”: 566, “responseCode”: 200, “count”: 817, “data”: [{“id”: 247, “flags”: 135, “listName”: “Their somebody law realize cause trip.”, “defaultValue”: false, “domainPatternBase”: “When town agency similar truth information break explain.”, “domainPattern”: “Ready treat provide direction go keep manager.”, “publicPrefixMatch”: false, “wildcardMatch”: true, “deleted”: false, “expired”: false, “lastUpdatedTimestamp”: 481959664}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Give mission however.”, “messageTemplate”: “Subject rate take break animal through manage.”, “field”: “Music play crime team pressure.”, “parameter”: {}, “timestamp”: 1334143788}], “currentPage”: 872, “size”: 574}

`api.reputation.v1.override.override_domain.` `get_overrides_for_i_p`(ip: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Look up domain override value by IP address (INTERNAL)

  Return type: | `dict`
  Parameters: | ip (str) – IP to search overrides for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 463, “limit”: 615, “responseCode”: 200, “count”: 542, “data”: [{“id”: 477, “flags”: 283, “listName”: “Himself send culture company.”, “defaultValue”: true, “deleted”: true, “expired”: true, “lastUpdatedTimestamp”: 868698948}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “People exactly become fear him character.”, “messageTemplate”: “Line purpose able whole.”, “field”: “Career her could else a late.”, “parameter”: {}, “timestamp”: 1348642079}], “currentPage”: 275, “size”: 335}

`api.reputation.v1.override.override_domain.` `list_address_overrides`(list: str = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List address overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | list (str) – Limit results to overrides from this list limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 733, “limit”: 951, “responseCode”: 200, “count”: 853, “data”: [{“id”: 831, “flags”: 693, “listName”: “To our teach because month huge.”, “defaultValue”: false, “deleted”: false, “expired”: true, “lastUpdatedTimestamp”: 539145432}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Nature easy dinner pull fight.”, “messageTemplate”: “Factor every activity plant choice ahead answer wonder.”, “field”: “Each amount fire base firm financial.”, “parameter”: {}, “timestamp”: 1237763656}], “currentPage”: 889, “size”: 247}

`api.reputation.v1.override.override_domain.` `list_domain_overrides`(list: str = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List domain overrides (INTERNAL)

  Return type: | `dict`
  Parameters: | list (str) – Limit results to overrides from this list limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 626, “limit”: 51, “responseCode”: 200, “count”: 136, “data”: [{“id”: 825, “flags”: 194, “listName”: “Them modern eight strong purpose wall.”, “defaultValue”: false, “domainPatternBase”: “Fine occur color.”, “domainPattern”: “Begin color language design run court.”, “publicPrefixMatch”: false, “wildcardMatch”: false, “deleted”: true, “expired”: true, “lastUpdatedTimestamp”: 219796236}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Build finally treat standard beyond participant high.”, “messageTemplate”: “Bed mean need future doctor country.”, “field”: “Course leader guess discuss system.”, “parameter”: {}, “timestamp”: 300196630}], “currentPage”: 735, “size”: 770}

`api.reputation.v1.override.override_domain.` `update_override_list`(id: int, name: str = None, description: str = None, useForReputationCalc: bool = 'False', useForInputFiltering: bool = 'False', useForDefaultValues: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update reputation override list (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of reputation override list name (str) – If set, update the name of this list => [a-zA-Z0-9_-.]* description (str) – If set, update the description of this list => [sw{}$-().[]“‘_/,*+#:@!?;]* useForReputationCalc (bool) – If set, enable/disable use of the overrides in this list when calculating reputation values useForInputFiltering (bool) – If set, enable/disable use of the overrides in this list for observation input filtering useForDefaultValues (bool) – If set, enable/disable use of the overrides in this list as default values
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 3, “limit”: 901, “responseCode”: 200, “count”: 503, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Approach partner environmental improve.”, “messageTemplate”: “Natural black customer tonight expect.”, “field”: “Take your most ahead practice American.”, “parameter”: {}, “timestamp”: 382286229}], “currentPage”: 360, “size”: 898}

## Module contents